@@ -1,8 +1,9 @@
 /* sane - Scanner Access Now Easy.
 
    Copyright (C) 2003, 2004 Henning Meier-Geinitz <henning@meier-geinitz.de>
-   Copyright (C) 2005 Stephane Voltz <svoltz@numericable.fr>
+   Copyright (C) 2005-2010 Stephane Voltz <stef.dev@free.fr>
    Copyright (C) 2006 Laurent Charpentier <laurent_pubs@yahoo.com>
+   Copyright (C) 2009 Pierre Willenbrock <pierre@pirsoft.dnsalias.org>
    
    This file is part of the SANE package.
    
@@ -55,13 +56,15 @@
 #define GENESYS_CONFIG_FILE "genesys.conf"
 
 /* Maximum time for lamp warm-up */
-#define WARMUP_TIME 45
+#define WARMUP_TIME 65
+
+#define FLATBED "Flatbed"
+#define TRANSPARENCY_ADAPTER "Transparency Adapter"
 
 #ifndef SANE_I18N
 #define SANE_I18N(text) text
 #endif
 
-
 /** List of SANE options
  */
 enum Genesys_Option
@@ -81,17 +84,41 @@ enum Genesys_Option
   OPT_BR_X,			/* bottom-right x */
   OPT_BR_Y,			/* bottom-right y */
 
+  /* advanced image enhancement options */
+  OPT_ENHANCEMENT_GROUP,
+  OPT_CUSTOM_GAMMA,		/* toggle to enable custom gamma tables */
+  OPT_GAMMA_VECTOR,
+  OPT_GAMMA_VECTOR_R,
+  OPT_GAMMA_VECTOR_G,
+  OPT_GAMMA_VECTOR_B,
+
   OPT_EXTRAS_GROUP,
   OPT_LAMP_OFF_TIME,
   OPT_THRESHOLD,
+  OPT_THRESHOLD_CURVE,
+  OPT_DISABLE_DYNAMIC_LINEART,
   OPT_DISABLE_INTERPOLATION,
   OPT_COLOR_FILTER,
+
+  OPT_SENSOR_GROUP,
+  OPT_SCAN_SW,
+  OPT_FILE_SW,
+  OPT_EMAIL_SW,
+  OPT_COPY_SW,
+  OPT_PAGE_LOADED_SW,
+  OPT_OCR_SW,
+  OPT_POWER_SW,
+  OPT_NEED_CALIBRATION_SW,
+  OPT_BUTTON_GROUP,
+  OPT_CALIBRATE,
+  OPT_CLEAR_CALIBRATION,
+
   /* must come last: */
   NUM_OPTIONS
 };
 
 
-/** Scanner object.
+/** Scanner object. Should have better be called Session than Scanner
  */
 typedef struct Genesys_Scanner
 {
@@ -102,6 +129,7 @@ typedef struct Genesys_Scanner
   SANE_Bool scanning;			   /**< We are currently scanning */
   SANE_Option_Descriptor opt[NUM_OPTIONS]; /**< Option descriptors */
   Option_Value val[NUM_OPTIONS];	   /**< Option values */
+  Option_Value last_val[NUM_OPTIONS];	   /**< Option values as read by the frontend. used for sensors. */
   SANE_Parameters params;		   /**< SANE Parameters */
   SANE_Int bpp_list[5];			   /**< */
 } Genesys_Scanner;
