@@ -1,15 +1,10 @@
-/*.............................................................................
- * Project : SANE library for Plustek parallelport flatbed scanners.
- *.............................................................................
- */
-
-/* @file plustek-pp_dac.c -
+/* @file plustek-pp_dac.c
  * @brief all the shading function formerly found in shading.c.
  *        don't ask me why I called this file dac.c...
  *
  * based on sources acquired from Plustek Inc.
  * Copyright (C) 1998 Plustek Inc.
- * Copyright (C) 2000-2003 Gerhard Jaeger <gerhard@gjaeger.de>
+ * Copyright (C) 2000-2004 Gerhard Jaeger <gerhard@gjaeger.de>
  * also based on the work done by Rick Bronson
  *
  * History:
@@ -30,6 +25,7 @@
  * - 0.40 - disabled the A3I stuff
  * - 0.41 - no changes
  * - 0.42 - changed include names
+ * - 0.43 - no changes
  * .
  * <hr>
  * This file is part of the SANE package.
@@ -2410,8 +2406,8 @@ static Bool dacP98003WaitForShading( pScanData ps )
     	ps->Bufs.b1.Buf.pdw[i+3] = tmp;
     }
 
-    memcpy( ps->Bufs.b1.pShadingMap, ps->Bufs.b1.pShadingMap + 4096, 4096 );
-    memcpy( ps->Bufs.b1.pShadingMap, ps->Bufs.b1.pShadingMap + 8192, 4096 );
+    memcpy( ps->Bufs.b1.pShadingMap + 4096, ps->Bufs.b1.pShadingMap, 4096 );
+    memcpy( ps->Bufs.b1.pShadingMap + 8192, ps->Bufs.b1.pShadingMap, 4096 );
     dacP98DownloadMapTable( ps, ps->Bufs.b1.pShadingMap );
 
     DBG( DBG_LOW, "wExposure = %u\n", ps->Shade.wExposure);
