@@ -827,6 +827,8 @@ read_files (void)
 		{
 		  type_entry *current_type = current_backend->type;
 		  int no_usbids = 0;
+		  int no_interface = 0;
+		  int no_status = 0;
 		  
 		  while (current_type)
 		    {
@@ -844,19 +846,21 @@ read_files (void)
 				{
 				  if (current_model->status == status_unknown)
 				    {
-				      DBG_WARN
+				      DBG_INFO
 					("Backend `%s': `%s' `%s' does not have a status\n",
 					 current_backend->name,
 					 current_mfg->name,
 					 current_model->name);
+				      no_status++;
 				    }
 				  if (!current_model->interface)
 				    {
-				      DBG_WARN
+				      DBG_INFO
 					("Backend `%s': `%s' `%s' does not have an interface\n",
 					 current_backend->name,
 					 current_mfg->name,
 					 current_model->name);
+				      no_interface++;
 				    }
 				  else if (strstr (current_model->interface, "USB"))
 				    {
@@ -878,6 +882,16 @@ read_files (void)
 			}
 		      current_type = current_type->next;
 		    }
+		  if (no_status)
+		    {
+		      DBG_WARN ("Backend `%s': %d devices without :status\n", 
+				current_backend->name, no_status);
+		    }
+		  if (no_interface)
+		    {
+		      DBG_WARN ("Backend `%s': %d devices without :interface\n", 
+				current_backend->name, no_interface);
+		    }
 		  if (no_usbids)
 		    {
 		      DBG_WARN ("Backend `%s': %d USB devices without :usbid\n", 
@@ -1523,6 +1537,12 @@ read_files (void)
 	      fclose (fp);
 	    }			/* if (strlen) */
 	}			/* while (direntry) */
+      if (closedir(dir) != 0)
+	{
+	  DBG_ERR ("cannot close directory `%s' (%s)\n", search_dir,
+		   strerror (errno));
+	  return SANE_FALSE;
+	}
       if (end)
 	search_dir = end + 1;
       else
@@ -3277,20 +3297,25 @@ print_usermap_header (void)
 {
   time_t current_time = time (0);
 
-  printf ("# This file was automatically created based on description files (*.desc)\n"
-	  "# by sane-desc %s from %s on %s",
-	  SANE_DESC_VERSION, PACKAGE_STRING, asctime (localtime (&current_time)));
   printf
-    ("#\n"
-     "# The entries below are used to detect a USB device when it's plugged in\n"
-     "# and then run the libusbscanner script to change the ownership and\n"
-     "# permissions on the \"device node\" used by libusb.\n"
+    ("# This file was automatically created based on description files (*.desc)\n"
+    "# by sane-desc %s from %s on %s"
+    "#\n"
+    ,
+    SANE_DESC_VERSION, PACKAGE_STRING, asctime (localtime (&current_time)));
+
+  printf
+     ("# The entries below are used to detect a USB device and change owner\n"
+     "# and permissions on the \"device node\" used by libusb.\n"
      "#\n"
      "# The 0x0003 match flag means the device is matched by its vendor and\n"
      "# product IDs.\n"
      "#\n"
      "# Sample entry (replace 0xVVVV and 0xPPPP with vendor ID and product ID\n"
-     "# respectively):\n");
+     "# respectively):\n"
+     "#\n"
+     );
+
   printf
     ("# libusbscanner 0x0003 0xVVVV 0xPPPP 0x0000 0x0000 0x00 0x00 0x00 0x00 "
      "0x00 0x00 0x00000000\n"
@@ -3298,10 +3323,20 @@ print_usermap_header (void)
      "bDeviceClass bDeviceSubClass bDeviceProtocol bInterfaceClass "
      "bInterfaceSubClass bInterfaceProtocol driver_info\n"
      "#\n"
-     "# The following list already contains a lot of scanners. If your scanner\n"
-     "# isn't mentioned there, add it as explained above and mail the entry to\n"
+     );
+
+  printf
+     ("# If your scanner isn't listed below, you can add it as explained above.\n"
+     "#\n"
+     "# If your scanner is supported by some external backend (brother, epkowa,\n"
+     "# hpaio, etc) please ask the author of the backend to provide proper\n"
+     "# device detection support for your OS\n"
+     "#\n"
+     "# If the scanner is supported by sane-backends, please mail the entry to\n"
      "# the sane-devel mailing list (sane-devel@lists.alioth.debian.org).\n"
-     "#\n");
+     "#\n"
+     );
+
 }
 
 static void
@@ -3353,13 +3388,21 @@ print_db_header (void)
      "#   product ID\n"
      "#   ownership (user:group)\n"
      "#   permissions\n"
-     "#   path of an optional script to run (it can be omitted)\n", DEVOWNER, DEVGROUP, DEVMODE);
+     "#   path of an optional script to run (it can be omitted)\n"
+     "#\n"
+     , DEVOWNER, DEVGROUP, DEVMODE);
+
   printf
-    ("#\n"
-     "# The following list already contains a lot of scanners. If your scanner\n"
-     "# isn't mentioned there, add it as explained above and mail the entry to\n"
+     ("# If your scanner isn't listed below, you can add it as explained above.\n"
+     "#\n"
+     "# If your scanner is supported by some external backend (brother, epkowa,\n"
+     "# hpaio, etc) please ask the author of the backend to provide proper\n"
+     "# device detection support for your OS\n"
+     "#\n"
+     "# If the scanner is supported by sane-backends, please mail the entry to\n"
      "# the sane-devel mailing list (sane-devel@lists.alioth.debian.org).\n"
-     "#\n");
+     "#\n"
+     );
 }
 
 static void
@@ -3410,13 +3453,20 @@ print_udev_header (void)
      "# LABEL=\"libsane_usb_rules_begin\" and LABEL=\"libsane_usb_rules_end\" lines.\n"
      "#\n"
      "# To run a script when your device is plugged in, add RUN+=\"/path/to/script\"\n"
-     "# to the appropriate rule.\n");
+     "# to the appropriate rule.\n"
+     "#\n"
+     );
   printf
-    ("#\n"
-     "# The following list already contains a lot of scanners. If your scanner\n"
-     "# isn't mentioned there, add it as explained above and mail the entry to\n"
+     ("# If your scanner isn't listed below, you can add it as explained above.\n"
+     "#\n"
+     "# If your scanner is supported by some external backend (brother, epkowa,\n"
+     "# hpaio, etc) please ask the author of the backend to provide proper\n"
+     "# device detection support for your OS\n"
+     "#\n"
+     "# If the scanner is supported by sane-backends, please mail the entry to\n"
      "# the sane-devel mailing list (sane-devel@lists.alioth.debian.org).\n"
-     "#\n\n");
+     "#\n"
+     );
 }
 
 static void
@@ -3440,7 +3490,7 @@ print_udev (void)
 
   printf("# For Linux >= 2.6.22 without CONFIG_USB_DEVICE_CLASS=y\n"
 	 "# If the following rule does not exist on your system yet, uncomment it\n"
-	 "# ENV{DEVTYPE}==\"usb_device\", NAME=\"bus/usb/$env{BUSNUM}/$env{DEVNUM}\", "
+	 "# ENV{DEVTYPE}==\"usb_device\", "
 	 "MODE=\"0664\", OWNER=\"root\", GROUP=\"root\"\n"
 	 "\n");
 
@@ -3475,7 +3525,7 @@ print_udev (void)
 	    }
 	}
       printf ("\n");
-      printf ("ATTR{idVendor}==\"%s\", ATTR{idProduct}==\"%s\", MODE=\"%s\", GROUP=\"%s\", ENV{libsane_matched}=\"yes\"\n",
+      printf ("ATTRS{idVendor}==\"%s\", ATTRS{idProduct}==\"%s\", MODE=\"%s\", GROUP=\"%s\", ENV{libsane_matched}=\"yes\"\n",
 	      usbid->usb_vendor_id + 2,  usbid->usb_product_id + 2, DEVMODE, DEVGROUP);
       usbid = usbid->next;
     }
@@ -3488,7 +3538,7 @@ print_udev (void)
   printf ("SUBSYSTEMS!=\"scsi\", GOTO=\"libsane_scsi_rules_end\"\n\n");
   printf ("LABEL=\"libsane_scsi_rules_begin\"\n");
   printf ("# Generic: SCSI device type 6 indicates a scanner\n");
-  printf ("KERNEL==\"sg[0-9]*\", NAME=\"%%k\", ATTRS{type}==\"6\", MODE=\"%s\", GROUP=\"%s\"\n", DEVMODE, DEVGROUP);
+  printf ("KERNEL==\"sg[0-9]*\", ATTRS{type}==\"6\", MODE=\"%s\", GROUP=\"%s\"\n", DEVMODE, DEVGROUP);
   printf ("# Some scanners advertise themselves as SCSI device type 3\n");
 
   while (scsiid)
@@ -3521,7 +3571,7 @@ print_udev (void)
 	    }
         }
       printf ("\n");
-      printf ("KERNEL==\"sg[0-9]*\", NAME=\"%%k\", ATTRS{type}==\"3\", ATTRS{vendor}==\"%s\", ATTRS{model}==\"%s\", MODE=\"%s\", GROUP=\"%s\"\n",
+      printf ("KERNEL==\"sg[0-9]*\", ATTRS{type}==\"3\", ATTRS{vendor}==\"%s\", ATTRS{model}==\"%s\", MODE=\"%s\", GROUP=\"%s\"\n",
 	      scsiid->scsi_vendor_id, scsiid->scsi_product_id, DEVMODE, DEVGROUP);
       scsiid = scsiid->next;
     }
